/*
 * Uht header class
 * Coded by mcidclan. April 2010
 * m.cid.clan@gmail.com
 *
 */

#ifndef H_UHT
#define H_UHT

#include "uht_necessary.h"

//Define the output frame dimension
#define WW 160
#define HH 120

//34ko for the max frame jpeg size that we can retained
#define MAX_VIDEO_FRAME_SIZE (1024*34)

//Buffers size using by the tracker
static const u32 SIZE_FBu8  = WW*HH;
static const u32 SIZE_FBu16 = SIZE_FBu8*2;
static const u32 SIZE_FBu32 = SIZE_FBu16*2;

class Uht{

	public:

	//Contains blob tracking informations
	//pOut.x, pOut.y, pOut.z, pOut.w for
	//X begin, X end, Y begin, Y end
	vec4i pOut;

	//Output frame buffers
	u32 *FB_MPEG;
	u32 *FB_8888;
	u16 *FB_565;

	bool run; //Is true when streaming working well
	bool direction; //sceUsbCamGetLensDirection

	//Set it to true before delete
	//to keep modules/drivers in running state
	bool relativeClean;

	int thid; //Thread id

	//Pass true if you seek to use 565 frame buffer.
	Uht();

	void fm_activated(); //Active the Frame Manager
	bool fm_isWaiting(); //Return True if the FM is waiting for a "next frame" signal
	void fm_nextFrame(); //Send a "next frame" signal

	//Except the working buffer pointer used by the tracker
	//Set dRender to true to turn off the blur filter 
	//Set fb565 to true to use the RGB_565
	void initBuffer(void *bWork, bool dRender, bool fb565);

	void setGrid(u8 cellSize, u8 pixTol);
	void setMinDim(u8 xMin, u8 yMin);

	//Init the camera and the corresponding video thread.
	//Pass thread's priority as argument
	int initCam(u8 prop = 0x10);

	~Uht(); //Delete and unload/stop all modules/drivers

	private:

	//Driver buffer workplace
	u8  work[1024*68] __attribute__((aligned(64)));
	
	//Frame jpeg buffer
	u8  buffer[MAX_VIDEO_FRAME_SIZE] __attribute__((aligned(64)));
};

#endif
